about summary refs log tree commit diff stats
path: root/code/fm/fm.rb
diff options
context:
space:
mode:
Diffstat (limited to 'code/fm/fm.rb')
-rw-r--r--code/fm/fm.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/code/fm/fm.rb b/code/fm/fm.rb
index 81b868ca..8e60286b 100644
--- a/code/fm/fm.rb
+++ b/code/fm/fm.rb
@@ -58,7 +58,7 @@ module Fm
 		@memory['0'] = pwd
 
 		# Give me some way to redraw screen while waiting for
 		# input from Interface.geti
 
 #		for i in 1..20
 #			eval "Signal.trap(#{i}) do
@@ -98,7 +98,7 @@ module Fm
 	end
 
 	def lines
-		Interface::lines - @bars.size
+		CLI::lines - @bars.size
 	end
 
 	def dump
@@ -58,7 +58,7 @@ module Fm
 
 		# Give me some way to redraw screen while waiting for
-		# input from Interface.geti
+		# input from CLI.geti
 
 #		for i in 1..20